# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/metric.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import label_pb2 as google_dot_api_dot_label__pb2
from google.api import launch_stage_pb2 as google_dot_api_dot_launch__stage__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17google/api/metric.proto\x12\ngoogle.api\x1a\x16google/api/label.proto\x1a\x1dgoogle/api/launch_stage.proto\x1a\x1egoogle/protobuf/duration.proto\"\x9f\x06\n\x10MetricDescriptor\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x08 \x01(\t\x12+\n\x06labels\x18\x02 \x03(\x0b\x32\x1b.google.api.LabelDescriptor\x12<\n\x0bmetric_kind\x18\x03 \x01(\x0e\x32\'.google.api.MetricDescriptor.MetricKind\x12:\n\nvalue_type\x18\x04 \x01(\x0e\x32&.google.api.MetricDescriptor.ValueType\x12\x0c\n\x04unit\x18\x05 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x07 \x01(\t\x12G\n\x08metadata\x18\n \x01(\x0b\x32\x35.google.api.MetricDescriptor.MetricDescriptorMetadata\x12-\n\x0claunch_stage\x18\x0c \x01(\x0e\x32\x17.google.api.LaunchStage\x12 \n\x18monitored_resource_types\x18\r \x03(\t\x1a\xb0\x01\n\x18MetricDescriptorMetadata\x12\x31\n\x0claunch_stage\x18\x01 \x01(\x0e\x32\x17.google.api.LaunchStageB\x02\x18\x01\x12\x30\n\rsample_period\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12/\n\x0cingest_delay\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\"O\n\nMetricKind\x12\x1b\n\x17METRIC_KIND_UNSPECIFIED\x10\x00\x12\t\n\x05GAUGE\x10\x01\x12\t\n\x05\x44\x45LTA\x10\x02\x12\x0e\n\nCUMULATIVE\x10\x03\"q\n\tValueType\x12\x1a\n\x16VALUE_TYPE_UNSPECIFIED\x10\x00\x12\x08\n\x04\x42OOL\x10\x01\x12\t\n\x05INT64\x10\x02\x12\n\n\x06\x44OUBLE\x10\x03\x12\n\n\x06STRING\x10\x04\x12\x10\n\x0c\x44ISTRIBUTION\x10\x05\x12\t\n\x05MONEY\x10\x06\"u\n\x06Metric\x12\x0c\n\x04type\x18\x03 \x01(\t\x12.\n\x06labels\x18\x02 \x03(\x0b\x32\x1e.google.api.Metric.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42_\n\x0e\x63om.google.apiB\x0bMetricProtoP\x01Z7google.golang.org/genproto/googleapis/api/metric;metric\xa2\x02\x04GAPIb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.metric_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\016com.google.apiB\013MetricProtoP\001Z7google.golang.org/genproto/googleapis/api/metric;metric\242\002\004GAPI'
  _METRICDESCRIPTOR_METRICDESCRIPTORMETADATA.fields_by_name['launch_stage']._options = None
  _METRICDESCRIPTOR_METRICDESCRIPTORMETADATA.fields_by_name['launch_stage']._serialized_options = b'\030\001'
  _METRIC_LABELSENTRY._options = None
  _METRIC_LABELSENTRY._serialized_options = b'8\001'
  _globals['_METRICDESCRIPTOR']._serialized_start=127
  _globals['_METRICDESCRIPTOR']._serialized_end=926
  _globals['_METRICDESCRIPTOR_METRICDESCRIPTORMETADATA']._serialized_start=554
  _globals['_METRICDESCRIPTOR_METRICDESCRIPTORMETADATA']._serialized_end=730
  _globals['_METRICDESCRIPTOR_METRICKIND']._serialized_start=732
  _globals['_METRICDESCRIPTOR_METRICKIND']._serialized_end=811
  _globals['_METRICDESCRIPTOR_VALUETYPE']._serialized_start=813
  _globals['_METRICDESCRIPTOR_VALUETYPE']._serialized_end=926
  _globals['_METRIC']._serialized_start=928
  _globals['_METRIC']._serialized_end=1045
  _globals['_METRIC_LABELSENTRY']._serialized_start=1000
  _globals['_METRIC_LABELSENTRY']._serialized_end=1045
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/http/compressor/v2/compressor.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7envoy/config/filter/http/compressor/v2/compressor.proto\x12&envoy.config.filter.http.compressor.v2\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\"\xdf\x01\n\nCompressor\x12\x34\n\x0e\x63ontent_length\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x14\n\x0c\x63ontent_type\x18\x02 \x03(\t\x12\x1e\n\x16\x64isable_on_etag_header\x18\x03 \x01(\x08\x12%\n\x1dremove_accept_encoding_header\x18\x04 \x01(\x08\x12>\n\x0fruntime_enabled\x18\x05 \x01(\x0b\x32%.envoy.api.v2.core.RuntimeFeatureFlagB\xe0\x01\n4io.envoyproxy.envoy.config.filter.http.compressor.v2B\x0f\x43ompressorProtoP\x01ZZgithub.com/envoyproxy/go-control-plane/envoy/config/filter/http/compressor/v2;compressorv2\xf2\x98\xfe\x8f\x05-\x12+envoy.extensions.filters.http.compressor.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.filter.http.compressor.v2.compressor_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n4io.envoyproxy.envoy.config.filter.http.compressor.v2B\017CompressorProtoP\001ZZgithub.com/envoyproxy/go-control-plane/envoy/config/filter/http/compressor/v2;compressorv2\362\230\376\217\005-\022+envoy.extensions.filters.http.compressor.v3\272\200\310\321\006\002\020\001'
  _globals['_COMPRESSOR']._serialized_start=225
  _globals['_COMPRESSOR']._serialized_end=448
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/data/tap/v2alpha/http.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.data.tap.v2alpha import common_pb2 as envoy_dot_data_dot_tap_dot_v2alpha_dot_common__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!envoy/data/tap/v2alpha/http.proto\x12\x16\x65nvoy.data.tap.v2alpha\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a#envoy/data/tap/v2alpha/common.proto\x1a\x1dudpa/annotations/status.proto\"\xb7\x02\n\x11HttpBufferedTrace\x12\x42\n\x07request\x18\x01 \x01(\x0b\x32\x31.envoy.data.tap.v2alpha.HttpBufferedTrace.Message\x12\x43\n\x08response\x18\x02 \x01(\x0b\x32\x31.envoy.data.tap.v2alpha.HttpBufferedTrace.Message\x1a\x98\x01\n\x07Message\x12/\n\x07headers\x18\x01 \x03(\x0b\x32\x1e.envoy.api.v2.core.HeaderValue\x12*\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x1c.envoy.data.tap.v2alpha.Body\x12\x30\n\x08trailers\x18\x03 \x03(\x0b\x32\x1e.envoy.api.v2.core.HeaderValue\"\x9e\x03\n\x18HttpStreamedTraceSegment\x12\x10\n\x08trace_id\x18\x01 \x01(\x04\x12\x37\n\x0frequest_headers\x18\x02 \x01(\x0b\x32\x1c.envoy.api.v2.core.HeaderMapH\x00\x12:\n\x12request_body_chunk\x18\x03 \x01(\x0b\x32\x1c.envoy.data.tap.v2alpha.BodyH\x00\x12\x38\n\x10request_trailers\x18\x04 \x01(\x0b\x32\x1c.envoy.api.v2.core.HeaderMapH\x00\x12\x38\n\x10response_headers\x18\x05 \x01(\x0b\x32\x1c.envoy.api.v2.core.HeaderMapH\x00\x12;\n\x13response_body_chunk\x18\x06 \x01(\x0b\x32\x1c.envoy.data.tap.v2alpha.BodyH\x00\x12\x39\n\x11response_trailers\x18\x07 \x01(\x0b\x32\x1c.envoy.api.v2.core.HeaderMapH\x00\x42\x0f\n\rmessage_pieceBz\n$io.envoyproxy.envoy.data.tap.v2alphaB\tHttpProtoP\x01Z=github.com/envoyproxy/go-control-plane/envoy/data/tap/v2alpha\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.data.tap.v2alpha.http_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$io.envoyproxy.envoy.data.tap.v2alphaB\tHttpProtoP\001Z=github.com/envoyproxy/go-control-plane/envoy/data/tap/v2alpha\272\200\310\321\006\002\020\001'
  _globals['_HTTPBUFFEREDTRACE']._serialized_start=160
  _globals['_HTTPBUFFEREDTRACE']._serialized_end=471
  _globals['_HTTPBUFFEREDTRACE_MESSAGE']._serialized_start=319
  _globals['_HTTPBUFFEREDTRACE_MESSAGE']._serialized_end=471
  _globals['_HTTPSTREAMEDTRACESEGMENT']._serialized_start=474
  _globals['_HTTPSTREAMEDTRACESEGMENT']._serialized_end=888
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/discovery/v2/hds.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.api.v2.core import health_check_pb2 as envoy_dot_api_dot_v2_dot_core_dot_health__check__pb2
from envoy.api.v2.endpoint import endpoint_components_pb2 as envoy_dot_api_dot_v2_dot_endpoint_dot_endpoint__components__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$envoy/service/discovery/v2/hds.proto\x12\x1a\x65nvoy.service.discovery.v2\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a$envoy/api/v2/core/health_check.proto\x1a/envoy/api/v2/endpoint/endpoint_components.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\"\x87\x01\n\nCapability\x12O\n\x16health_check_protocols\x18\x01 \x03(\x0e\x32/.envoy.service.discovery.v2.Capability.Protocol\"(\n\x08Protocol\x12\x08\n\x04HTTP\x10\x00\x12\x07\n\x03TCP\x10\x01\x12\t\n\x05REDIS\x10\x02\"w\n\x12HealthCheckRequest\x12%\n\x04node\x18\x01 \x01(\x0b\x32\x17.envoy.api.v2.core.Node\x12:\n\ncapability\x18\x02 \x01(\x0b\x32&.envoy.service.discovery.v2.Capability\"{\n\x0e\x45ndpointHealth\x12\x31\n\x08\x65ndpoint\x18\x01 \x01(\x0b\x32\x1f.envoy.api.v2.endpoint.Endpoint\x12\x36\n\rhealth_status\x18\x02 \x01(\x0e\x32\x1f.envoy.api.v2.core.HealthStatus\"^\n\x16\x45ndpointHealthResponse\x12\x44\n\x10\x65ndpoints_health\x18\x01 \x03(\x0b\x32*.envoy.service.discovery.v2.EndpointHealth\"\xe4\x01\n*HealthCheckRequestOrEndpointHealthResponse\x12N\n\x14health_check_request\x18\x01 \x01(\x0b\x32..envoy.service.discovery.v2.HealthCheckRequestH\x00\x12V\n\x18\x65ndpoint_health_response\x18\x02 \x01(\x0b\x32\x32.envoy.service.discovery.v2.EndpointHealthResponseH\x00\x42\x0e\n\x0crequest_type\"v\n\x11LocalityEndpoints\x12-\n\x08locality\x18\x01 \x01(\x0b\x32\x1b.envoy.api.v2.core.Locality\x12\x32\n\tendpoints\x18\x02 \x03(\x0b\x32\x1f.envoy.api.v2.endpoint.Endpoint\"\xac\x01\n\x12\x43lusterHealthCheck\x12\x14\n\x0c\x63luster_name\x18\x01 \x01(\t\x12\x35\n\rhealth_checks\x18\x02 \x03(\x0b\x32\x1e.envoy.api.v2.core.HealthCheck\x12I\n\x12locality_endpoints\x18\x03 \x03(\x0b\x32-.envoy.service.discovery.v2.LocalityEndpoints\"\x92\x01\n\x14HealthCheckSpecifier\x12M\n\x15\x63luster_health_checks\x18\x01 \x03(\x0b\x32..envoy.service.discovery.v2.ClusterHealthCheck\x12+\n\x08interval\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration2\xe4\x02\n\x16HealthDiscoveryService\x12\x93\x01\n\x11StreamHealthCheck\x12\x46.envoy.service.discovery.v2.HealthCheckRequestOrEndpointHealthResponse\x1a\x30.envoy.service.discovery.v2.HealthCheckSpecifier\"\x00(\x01\x30\x01\x12\xb3\x01\n\x10\x46\x65tchHealthCheck\x12\x46.envoy.service.discovery.v2.HealthCheckRequestOrEndpointHealthResponse\x1a\x30.envoy.service.discovery.v2.HealthCheckSpecifier\"%\x82\xd3\xe4\x93\x02\x1f\"\x1a/v2/discovery:health_check:\x01*B\xac\x01\n(io.envoyproxy.envoy.service.discovery.v2B\x08HdsProtoP\x01ZMgithub.com/envoyproxy/go-control-plane/envoy/service/discovery/v2;discoveryv2\xf2\x98\xfe\x8f\x05\x19\x12\x17\x65nvoy.service.health.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.service.discovery.v2.hds_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(io.envoyproxy.envoy.service.discovery.v2B\010HdsProtoP\001ZMgithub.com/envoyproxy/go-control-plane/envoy/service/discovery/v2;discoveryv2\362\230\376\217\005\031\022\027envoy.service.health.v3\272\200\310\321\006\002\020\001'
  _HEALTHDISCOVERYSERVICE.methods_by_name['FetchHealthCheck']._options = None
  _HEALTHDISCOVERYSERVICE.methods_by_name['FetchHealthCheck']._serialized_options = b'\202\323\344\223\002\037\"\032/v2/discovery:health_check:\001*'
  _globals['_CAPABILITY']._serialized_start=311
  _globals['_CAPABILITY']._serialized_end=446
  _globals['_CAPABILITY_PROTOCOL']._serialized_start=406
  _globals['_CAPABILITY_PROTOCOL']._serialized_end=446
  _globals['_HEALTHCHECKREQUEST']._serialized_start=448
  _globals['_HEALTHCHECKREQUEST']._serialized_end=567
  _globals['_ENDPOINTHEALTH']._serialized_start=569
  _globals['_ENDPOINTHEALTH']._serialized_end=692
  _globals['_ENDPOINTHEALTHRESPONSE']._serialized_start=694
  _globals['_ENDPOINTHEALTHRESPONSE']._serialized_end=788
  _globals['_HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE']._serialized_start=791
  _globals['_HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE']._serialized_end=1019
  _globals['_LOCALITYENDPOINTS']._serialized_start=1021
  _globals['_LOCALITYENDPOINTS']._serialized_end=1139
  _globals['_CLUSTERHEALTHCHECK']._serialized_start=1142
  _globals['_CLUSTERHEALTHCHECK']._serialized_end=1314
  _globals['_HEALTHCHECKSPECIFIER']._serialized_start=1317
  _globals['_HEALTHCHECKSPECIFIER']._serialized_end=1463
  _globals['_HEALTHDISCOVERYSERVICE']._serialized_start=1466
  _globals['_HEALTHDISCOVERYSERVICE']._serialized_end=1822
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/client.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17google/api/client.proto\x12\ngoogle.api\x1a google/protobuf/descriptor.proto:9\n\x10method_signature\x12\x1e.google.protobuf.MethodOptions\x18\x9b\x08 \x03(\t:6\n\x0c\x64\x65\x66\x61ult_host\x12\x1f.google.protobuf.ServiceOptions\x18\x99\x08 \x01(\t:6\n\x0coauth_scopes\x12\x1f.google.protobuf.ServiceOptions\x18\x9a\x08 \x01(\tBi\n\x0e\x63om.google.apiB\x0b\x43lientProtoP\x01ZAgoogle.golang.org/genproto/googleapis/api/annotations;annotations\xa2\x02\x04GAPIb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.client_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  google_dot_protobuf_dot_descriptor__pb2.MethodOptions.RegisterExtension(method_signature)
  google_dot_protobuf_dot_descriptor__pb2.ServiceOptions.RegisterExtension(default_host)
  google_dot_protobuf_dot_descriptor__pb2.ServiceOptions.RegisterExtension(oauth_scopes)

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\016com.google.apiB\013ClientProtoP\001ZAgoogle.golang.org/genproto/googleapis/api/annotations;annotations\242\002\004GAPI'
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/fault/v3/fault.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.route.v3 import route_components_pb2 as envoy_dot_config_dot_route_dot_v3_dot_route__components__pb2
from envoy.extensions.filters.common.fault.v3 import fault_pb2 as envoy_dot_extensions_dot_filters_dot_common_dot_fault_dot_v3_dot_fault__pb2
from envoy.type.v3 import percent_pb2 as envoy_dot_type_dot_v3_dot_percent__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2envoy/extensions/filters/http/fault/v3/fault.proto\x12&envoy.extensions.filters.http.fault.v3\x1a,envoy/config/route/v3/route_components.proto\x1a\x34\x65nvoy/extensions/filters/common/fault/v3/fault.proto\x1a\x1b\x65nvoy/type/v3/percent.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xf3\x02\n\nFaultAbort\x12\"\n\x0bhttp_status\x18\x02 \x01(\rB\x0b\xfa\x42\x08*\x06\x10\xd8\x04(\xc8\x01H\x00\x12\x15\n\x0bgrpc_status\x18\x05 \x01(\rH\x00\x12V\n\x0cheader_abort\x18\x04 \x01(\x0b\x32>.envoy.extensions.filters.http.fault.v3.FaultAbort.HeaderAbortH\x00\x12\x34\n\npercentage\x18\x03 \x01(\x0b\x32 .envoy.type.v3.FractionalPercent\x1aN\n\x0bHeaderAbort:?\x9a\xc5\x88\x1e:\n8envoy.config.filter.http.fault.v2.FaultAbort.HeaderAbort:3\x9a\xc5\x88\x1e.\n,envoy.config.filter.http.fault.v2.FaultAbortB\x11\n\nerror_type\x12\x03\xf8\x42\x01J\x04\x08\x01\x10\x02\"\x92\x06\n\tHTTPFault\x12\x43\n\x05\x64\x65lay\x18\x01 \x01(\x0b\x32\x34.envoy.extensions.filters.common.fault.v3.FaultDelay\x12\x41\n\x05\x61\x62ort\x18\x02 \x01(\x0b\x32\x32.envoy.extensions.filters.http.fault.v3.FaultAbort\x12\x18\n\x10upstream_cluster\x18\x03 \x01(\t\x12\x35\n\x07headers\x18\x04 \x03(\x0b\x32$.envoy.config.route.v3.HeaderMatcher\x12\x18\n\x10\x64ownstream_nodes\x18\x05 \x03(\t\x12\x37\n\x11max_active_faults\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12U\n\x13response_rate_limit\x18\x07 \x01(\x0b\x32\x38.envoy.extensions.filters.common.fault.v3.FaultRateLimit\x12\x1d\n\x15\x64\x65lay_percent_runtime\x18\x08 \x01(\t\x12\x1d\n\x15\x61\x62ort_percent_runtime\x18\t \x01(\t\x12\x1e\n\x16\x64\x65lay_duration_runtime\x18\n \x01(\t\x12!\n\x19\x61\x62ort_http_status_runtime\x18\x0b \x01(\t\x12!\n\x19max_active_faults_runtime\x18\x0c \x01(\t\x12+\n#response_rate_limit_percent_runtime\x18\r \x01(\t\x12!\n\x19\x61\x62ort_grpc_status_runtime\x18\x0e \x01(\t\x12(\n disable_downstream_cluster_stats\x18\x0f \x01(\x08\x12\x30\n\x0f\x66ilter_metadata\x18\x10 \x01(\x0b\x32\x17.google.protobuf.Struct:2\x9a\xc5\x88\x1e-\n+envoy.config.filter.http.fault.v2.HTTPFaultB\xa3\x01\n4io.envoyproxy.envoy.extensions.filters.http.fault.v3B\nFaultProtoP\x01ZUgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/fault/v3;faultv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.fault.v3.fault_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n4io.envoyproxy.envoy.extensions.filters.http.fault.v3B\nFaultProtoP\001ZUgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/fault/v3;faultv3\272\200\310\321\006\002\020\002'
  _FAULTABORT_HEADERABORT._options = None
  _FAULTABORT_HEADERABORT._serialized_options = b'\232\305\210\036:\n8envoy.config.filter.http.fault.v2.FaultAbort.HeaderAbort'
  _FAULTABORT.oneofs_by_name['error_type']._options = None
  _FAULTABORT.oneofs_by_name['error_type']._serialized_options = b'\370B\001'
  _FAULTABORT.fields_by_name['http_status']._options = None
  _FAULTABORT.fields_by_name['http_status']._serialized_options = b'\372B\010*\006\020\330\004(\310\001'
  _FAULTABORT._options = None
  _FAULTABORT._serialized_options = b'\232\305\210\036.\n,envoy.config.filter.http.fault.v2.FaultAbort'
  _HTTPFAULT._options = None
  _HTTPFAULT._serialized_options = b'\232\305\210\036-\n+envoy.config.filter.http.fault.v2.HTTPFault'
  _globals['_FAULTABORT']._serialized_start=377
  _globals['_FAULTABORT']._serialized_end=748
  _globals['_FAULTABORT_HEADERABORT']._serialized_start=592
  _globals['_FAULTABORT_HEADERABORT']._serialized_end=670
  _globals['_HTTPFAULT']._serialized_start=751
  _globals['_HTTPFAULT']._serialized_end=1537
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/listener/proxy_protocol/v2/proxy_protocol.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCenvoy/config/filter/listener/proxy_protocol/v2/proxy_protocol.proto\x12.envoy.config.filter.listener.proxy_protocol.v2\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\"\x0f\n\rProxyProtocolB\xff\x01\n<io.envoyproxy.envoy.config.filter.listener.proxy_protocol.v2B\x12ProxyProtocolProtoP\x01Zfgithub.com/envoyproxy/go-control-plane/envoy/config/filter/listener/proxy_protocol/v2;proxy_protocolv2\xf2\x98\xfe\x8f\x05\x35\x12\x33\x65nvoy.extensions.filters.listener.proxy_protocol.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.filter.listener.proxy_protocol.v2.proxy_protocol_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n<io.envoyproxy.envoy.config.filter.listener.proxy_protocol.v2B\022ProxyProtocolProtoP\001Zfgithub.com/envoyproxy/go-control-plane/envoy/config/filter/listener/proxy_protocol/v2;proxy_protocolv2\362\230\376\217\0055\0223envoy.extensions.filters.listener.proxy_protocol.v3\272\200\310\321\006\002\020\001'
  _globals['_PROXYPROTOCOL']._serialized_start=182
  _globals['_PROXYPROTOCOL']._serialized_end=197
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/matching/input_matchers/ip/v3/ip.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import address_pb2 as envoy_dot_config_dot_core_dot_v3_dot_address__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7envoy/extensions/matching/input_matchers/ip/v3/ip.proto\x12.envoy.extensions.matching.input_matchers.ip.v3\x1a\"envoy/config/core/v3/address.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"b\n\x02Ip\x12>\n\x0b\x63idr_ranges\x18\x01 \x03(\x0b\x32\x1f.envoy.config.core.v3.CidrRangeB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x12\x1c\n\x0bstat_prefix\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x42\xad\x01\n<io.envoyproxy.envoy.extensions.matching.input_matchers.ip.v3B\x07IpProtoP\x01ZZgithub.com/envoyproxy/go-control-plane/envoy/extensions/matching/input_matchers/ip/v3;ipv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.matching.input_matchers.ip.v3.ip_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n<io.envoyproxy.envoy.extensions.matching.input_matchers.ip.v3B\007IpProtoP\001ZZgithub.com/envoyproxy/go-control-plane/envoy/extensions/matching/input_matchers/ip/v3;ipv3\272\200\310\321\006\002\020\002'
  _IP.fields_by_name['cidr_ranges']._options = None
  _IP.fields_by_name['cidr_ranges']._serialized_options = b'\372B\005\222\001\002\010\001'
  _IP.fields_by_name['stat_prefix']._options = None
  _IP.fields_by_name['stat_prefix']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_IP']._serialized_start=199
  _globals['_IP']._serialized_end=297
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/common/dynamic_forward_proxy/v2alpha/dns_cache.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2 import cluster_pb2 as envoy_dot_api_dot_v2_dot_cluster__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAenvoy/config/common/dynamic_forward_proxy/v2alpha/dns_cache.proto\x12\x31\x65nvoy.config.common.dynamic_forward_proxy.v2alpha\x1a\x1a\x65nvoy/api/v2/cluster.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xec\x02\n\x0e\x44nsCacheConfig\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12J\n\x11\x64ns_lookup_family\x18\x02 \x01(\x0e\x32%.envoy.api.v2.Cluster.DnsLookupFamilyB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x41\n\x10\x64ns_refresh_rate\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0c\xfa\x42\t\xaa\x01\x06\x32\x04\x10\xc0\x84=\x12\x35\n\x08host_ttl\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12\x38\n\tmax_hosts\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02 \x00\x12\x43\n\x18\x64ns_failure_refresh_rate\x18\x06 \x01(\x0b\x32!.envoy.api.v2.Cluster.RefreshRateB\xec\x01\n?io.envoyproxy.envoy.config.common.dynamic_forward_proxy.v2alphaB\rDnsCacheProtoP\x01ZXgithub.com/envoyproxy/go-control-plane/envoy/config/common/dynamic_forward_proxy/v2alpha\xf2\x98\xfe\x8f\x05\x32\x12\x30\x65nvoy.extensions.common.dynamic_forward_proxy.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.common.dynamic_forward_proxy.v2alpha.dns_cache_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n?io.envoyproxy.envoy.config.common.dynamic_forward_proxy.v2alphaB\rDnsCacheProtoP\001ZXgithub.com/envoyproxy/go-control-plane/envoy/config/common/dynamic_forward_proxy/v2alpha\362\230\376\217\0052\0220envoy.extensions.common.dynamic_forward_proxy.v3\272\200\310\321\006\002\020\001'
  _DNSCACHECONFIG.fields_by_name['name']._options = None
  _DNSCACHECONFIG.fields_by_name['name']._serialized_options = b'\372B\004r\002 \001'
  _DNSCACHECONFIG.fields_by_name['dns_lookup_family']._options = None
  _DNSCACHECONFIG.fields_by_name['dns_lookup_family']._serialized_options = b'\372B\005\202\001\002\020\001'
  _DNSCACHECONFIG.fields_by_name['dns_refresh_rate']._options = None
  _DNSCACHECONFIG.fields_by_name['dns_refresh_rate']._serialized_options = b'\372B\t\252\001\0062\004\020\300\204='
  _DNSCACHECONFIG.fields_by_name['host_ttl']._options = None
  _DNSCACHECONFIG.fields_by_name['host_ttl']._serialized_options = b'\372B\005\252\001\002*\000'
  _DNSCACHECONFIG.fields_by_name['max_hosts']._options = None
  _DNSCACHECONFIG.fields_by_name['max_hosts']._serialized_options = b'\372B\004*\002 \000'
  _globals['_DNSCACHECONFIG']._serialized_start=301
  _globals['_DNSCACHECONFIG']._serialized_end=665
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/longrunning/operations.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2
from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#google/longrunning/operations.proto\x12\x12google.longrunning\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x17google/rpc/status.proto\x1a google/protobuf/descriptor.proto\"\xa8\x01\n\tOperation\x12\x0c\n\x04name\x18\x01 \x01(\t\x12&\n\x08metadata\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x0c\n\x04\x64one\x18\x03 \x01(\x08\x12#\n\x05\x65rror\x18\x04 \x01(\x0b\x32\x12.google.rpc.StatusH\x00\x12(\n\x08response\x18\x05 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x42\x08\n\x06result\"#\n\x13GetOperationRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"\\\n\x15ListOperationsRequest\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"d\n\x16ListOperationsResponse\x12\x31\n\noperations\x18\x01 \x03(\x0b\x32\x1d.google.longrunning.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"&\n\x16\x43\x61ncelOperationRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"&\n\x16\x44\x65leteOperationRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"P\n\x14WaitOperationRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12*\n\x07timeout\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\"=\n\rOperationInfo\x12\x15\n\rresponse_type\x18\x01 \x01(\t\x12\x15\n\rmetadata_type\x18\x02 \x01(\t2\xaa\x05\n\nOperations\x12\x94\x01\n\x0eListOperations\x12).google.longrunning.ListOperationsRequest\x1a*.google.longrunning.ListOperationsResponse\"+\xda\x41\x0bname,filter\x82\xd3\xe4\x93\x02\x17\x12\x15/v1/{name=operations}\x12\x7f\n\x0cGetOperation\x12\'.google.longrunning.GetOperationRequest\x1a\x1d.google.longrunning.Operation\"\'\xda\x41\x04name\x82\xd3\xe4\x93\x02\x1a\x12\x18/v1/{name=operations/**}\x12~\n\x0f\x44\x65leteOperation\x12*.google.longrunning.DeleteOperationRequest\x1a\x16.google.protobuf.Empty\"\'\xda\x41\x04name\x82\xd3\xe4\x93\x02\x1a*\x18/v1/{name=operations/**}\x12\x88\x01\n\x0f\x43\x61ncelOperation\x12*.google.longrunning.CancelOperationRequest\x1a\x16.google.protobuf.Empty\"1\xda\x41\x04name\x82\xd3\xe4\x93\x02$\"\x1f/v1/{name=operations/**}:cancel:\x01*\x12Z\n\rWaitOperation\x12(.google.longrunning.WaitOperationRequest\x1a\x1d.google.longrunning.Operation\"\x00\x1a\x1d\xca\x41\x1alongrunning.googleapis.com:Z\n\x0eoperation_info\x12\x1e.google.protobuf.MethodOptions\x18\x99\x08 \x01(\x0b\x32!.google.longrunning.OperationInfoB\x97\x01\n\x16\x63om.google.longrunningB\x0fOperationsProtoP\x01Z=google.golang.org/genproto/googleapis/longrunning;longrunning\xf8\x01\x01\xaa\x02\x12Google.LongRunning\xca\x02\x12Google\\LongRunningb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.longrunning.operations_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  google_dot_protobuf_dot_descriptor__pb2.MethodOptions.RegisterExtension(operation_info)

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026com.google.longrunningB\017OperationsProtoP\001Z=google.golang.org/genproto/googleapis/longrunning;longrunning\370\001\001\252\002\022Google.LongRunning\312\002\022Google\\LongRunning'
  _OPERATIONS._options = None
  _OPERATIONS._serialized_options = b'\312A\032longrunning.googleapis.com'
  _OPERATIONS.methods_by_name['ListOperations']._options = None
  _OPERATIONS.methods_by_name['ListOperations']._serialized_options = b'\332A\013name,filter\202\323\344\223\002\027\022\025/v1/{name=operations}'
  _OPERATIONS.methods_by_name['GetOperation']._options = None
  _OPERATIONS.methods_by_name['GetOperation']._serialized_options = b'\332A\004name\202\323\344\223\002\032\022\030/v1/{name=operations/**}'
  _OPERATIONS.methods_by_name['DeleteOperation']._options = None
  _OPERATIONS.methods_by_name['DeleteOperation']._serialized_options = b'\332A\004name\202\323\344\223\002\032*\030/v1/{name=operations/**}'
  _OPERATIONS.methods_by_name['CancelOperation']._options = None
  _OPERATIONS.methods_by_name['CancelOperation']._serialized_options = b'\332A\004name\202\323\344\223\002$\"\037/v1/{name=operations/**}:cancel:\001*'
  _globals['_OPERATION']._serialized_start=262
  _globals['_OPERATION']._serialized_end=430
  _globals['_GETOPERATIONREQUEST']._serialized_start=432
  _globals['_GETOPERATIONREQUEST']._serialized_end=467
  _globals['_LISTOPERATIONSREQUEST']._serialized_start=469
  _globals['_LISTOPERATIONSREQUEST']._serialized_end=561
  _globals['_LISTOPERATIONSRESPONSE']._serialized_start=563
  _globals['_LISTOPERATIONSRESPONSE']._serialized_end=663
  _globals['_CANCELOPERATIONREQUEST']._serialized_start=665
  _globals['_CANCELOPERATIONREQUEST']._serialized_end=703
  _globals['_DELETEOPERATIONREQUEST']._serialized_start=705
  _globals['_DELETEOPERATIONREQUEST']._serialized_end=743
  _globals['_WAITOPERATIONREQUEST']._serialized_start=745
  _globals['_WAITOPERATIONREQUEST']._serialized_end=825
  _globals['_OPERATIONINFO']._serialized_start=827
  _globals['_OPERATIONINFO']._serialized_end=888
  _globals['_OPERATIONS']._serialized_start=891
  _globals['_OPERATIONS']._serialized_end=1573
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/admin/v2alpha/listeners.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import address_pb2 as envoy_dot_api_dot_v2_dot_core_dot_address__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#envoy/admin/v2alpha/listeners.proto\x12\x13\x65nvoy.admin.v2alpha\x1a\x1f\x65nvoy/api/v2/core/address.proto\x1a\x1dudpa/annotations/status.proto\"K\n\tListeners\x12>\n\x11listener_statuses\x18\x01 \x03(\x0b\x32#.envoy.admin.v2alpha.ListenerStatus\"Q\n\x0eListenerStatus\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x31\n\rlocal_address\x18\x02 \x01(\x0b\x32\x1a.envoy.api.v2.core.AddressBy\n!io.envoyproxy.envoy.admin.v2alphaB\x0eListenersProtoP\x01Z:github.com/envoyproxy/go-control-plane/envoy/admin/v2alpha\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.admin.v2alpha.listeners_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!io.envoyproxy.envoy.admin.v2alphaB\016ListenersProtoP\001Z:github.com/envoyproxy/go-control-plane/envoy/admin/v2alpha\272\200\310\321\006\002\020\001'
  _globals['_LISTENERS']._serialized_start=124
  _globals['_LISTENERS']._serialized_end=199
  _globals['_LISTENERSTATUS']._serialized_start=201
  _globals['_LISTENERSTATUS']._serialized_end=282
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/geoip/v3/geoip.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import extension_pb2 as envoy_dot_config_dot_core_dot_v3_dot_extension__pb2
from xds.annotations.v3 import status_pb2 as xds_dot_annotations_dot_v3_dot_status__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2envoy/extensions/filters/http/geoip/v3/geoip.proto\x12&envoy.extensions.filters.http.geoip.v3\x1a$envoy/config/core/v3/extension.proto\x1a\x1fxds/annotations/v3/status.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xe0\x04\n\x05Geoip\x12K\n\nxff_config\x18\x01 \x01(\x0b\x32\x37.envoy.extensions.filters.http.geoip.v3.Geoip.XffConfig\x12k\n\x12geo_headers_to_add\x18\x02 \x01(\x0b\x32\x45.envoy.extensions.filters.http.geoip.v3.Geoip.GeolocationHeadersToAddB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x46\n\x08provider\x18\x03 \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x1a\xa9\x02\n\x17GeolocationHeadersToAdd\x12\x1c\n\x07\x63ountry\x18\x01 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x01\xd0\x01\x01\x12\x19\n\x04\x63ity\x18\x02 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x01\xd0\x01\x01\x12\x1b\n\x06region\x18\x03 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x01\xd0\x01\x01\x12\x18\n\x03\x61sn\x18\x04 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x01\xd0\x01\x01\x12\x1c\n\x07is_anon\x18\x05 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x01\xd0\x01\x01\x12\x1d\n\x08\x61non_vpn\x18\x06 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x01\xd0\x01\x01\x12!\n\x0c\x61non_hosting\x18\x07 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x01\xd0\x01\x01\x12\x1d\n\x08\x61non_tor\x18\x08 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x01\xd0\x01\x01\x12\x1f\n\nanon_proxy\x18\t \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x01\xd0\x01\x01\x1a)\n\tXffConfig\x12\x1c\n\x14xff_num_trusted_hops\x18\x01 \x01(\rB\xab\x01\n4io.envoyproxy.envoy.extensions.filters.http.geoip.v3B\nGeoipProtoP\x01ZUgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/geoip/v3;geoipv3\xba\x80\xc8\xd1\x06\x02\x10\x02\xd2\xc6\xa4\xe1\x06\x02\x08\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.geoip.v3.geoip_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n4io.envoyproxy.envoy.extensions.filters.http.geoip.v3B\nGeoipProtoP\001ZUgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/geoip/v3;geoipv3\272\200\310\321\006\002\020\002\322\306\244\341\006\002\010\001'
  _GEOIP_GEOLOCATIONHEADERSTOADD.fields_by_name['country']._options = None
  _GEOIP_GEOLOCATIONHEADERSTOADD.fields_by_name['country']._serialized_options = b'\372B\010r\006\300\001\001\320\001\001'
  _GEOIP_GEOLOCATIONHEADERSTOADD.fields_by_name['city']._options = None
  _GEOIP_GEOLOCATIONHEADERSTOADD.fields_by_name['city']._serialized_options = b'\372B\010r\006\300\001\001\320\001\001'
  _GEOIP_GEOLOCATIONHEADERSTOADD.fields_by_name['region']._options = None
  _GEOIP_GEOLOCATIONHEADERSTOADD.fields_by_name['region']._serialized_options = b'\372B\010r\006\300\001\001\320\001\001'
  _GEOIP_GEOLOCATIONHEADERSTOADD.fields_by_name['asn']._options = None
  _GEOIP_GEOLOCATIONHEADERSTOADD.fields_by_name['asn']._serialized_options = b'\372B\010r\006\300\001\001\320\001\001'
  _GEOIP_GEOLOCATIONHEADERSTOADD.fields_by_name['is_anon']._options = None
  _GEOIP_GEOLOCATIONHEADERSTOADD.fields_by_name['is_anon']._serialized_options = b'\372B\010r\006\300\001\001\320\001\001'
  _GEOIP_GEOLOCATIONHEADERSTOADD.fields_by_name['anon_vpn']._options = None
  _GEOIP_GEOLOCATIONHEADERSTOADD.fields_by_name['anon_vpn']._serialized_options = b'\372B\010r\006\300\001\001\320\001\001'
  _GEOIP_GEOLOCATIONHEADERSTOADD.fields_by_name['anon_hosting']._options = None
  _GEOIP_GEOLOCATIONHEADERSTOADD.fields_by_name['anon_hosting']._serialized_options = b'\372B\010r\006\300\001\001\320\001\001'
  _GEOIP_GEOLOCATIONHEADERSTOADD.fields_by_name['anon_tor']._options = None
  _GEOIP_GEOLOCATIONHEADERSTOADD.fields_by_name['anon_tor']._serialized_options = b'\372B\010r\006\300\001\001\320\001\001'
  _GEOIP_GEOLOCATIONHEADERSTOADD.fields_by_name['anon_proxy']._options = None
  _GEOIP_GEOLOCATIONHEADERSTOADD.fields_by_name['anon_proxy']._serialized_options = b'\372B\010r\006\300\001\001\320\001\001'
  _GEOIP.fields_by_name['geo_headers_to_add']._options = None
  _GEOIP.fields_by_name['geo_headers_to_add']._serialized_options = b'\372B\005\212\001\002\020\001'
  _GEOIP.fields_by_name['provider']._options = None
  _GEOIP.fields_by_name['provider']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_GEOIP']._serialized_start=222
  _globals['_GEOIP']._serialized_end=830
  _globals['_GEOIP_GEOLOCATIONHEADERSTOADD']._serialized_start=490
  _globals['_GEOIP_GEOLOCATIONHEADERSTOADD']._serialized_end=787
  _globals['_GEOIP_XFFCONFIG']._serialized_start=789
  _globals['_GEOIP_XFFCONFIG']._serialized_end=830
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/http/cache/file_system_http_cache/v3/file_system_http_cache.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.extensions.common.async_files.v3 import async_file_manager_pb2 as envoy_dot_extensions_dot_common_dot_async__files_dot_v3_dot_async__file__manager__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from xds.annotations.v3 import status_pb2 as xds_dot_annotations_dot_v3_dot_status__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nRenvoy/extensions/http/cache/file_system_http_cache/v3/file_system_http_cache.proto\x12\x35\x65nvoy.extensions.http.cache.file_system_http_cache.v3\x1a?envoy/extensions/common/async_files/v3/async_file_manager.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fxds/annotations/v3/status.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x9f\x04\n\x19\x46ileSystemHttpCacheConfig\x12`\n\x0emanager_config\x18\x01 \x01(\x0b\x32>.envoy.extensions.common.async_files.v3.AsyncFileManagerConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x1b\n\ncache_path\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12:\n\x14max_cache_size_bytes\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12K\n%max_individual_cache_entry_size_bytes\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12;\n\x15max_cache_entry_count\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12\x1a\n\x12\x63\x61\x63he_subdivisions\x18\x06 \x01(\r\x12\x16\n\x0e\x65vict_fraction\x18\x07 \x01(\x02\x12\x36\n\x13max_eviction_period\x18\x08 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x36\n\x13min_eviction_period\x18\t \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x19\n\x11\x63reate_cache_path\x18\n \x01(\x08\x42\xe8\x01\nCio.envoyproxy.envoy.extensions.http.cache.file_system_http_cache.v3B\x18\x46ileSystemHttpCacheProtoP\x01Zugithub.com/envoyproxy/go-control-plane/envoy/extensions/http/cache/file_system_http_cache/v3;file_system_http_cachev3\xba\x80\xc8\xd1\x06\x02\x10\x02\xd2\xc6\xa4\xe1\x06\x02\x08\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.http.cache.file_system_http_cache.v3.file_system_http_cache_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nCio.envoyproxy.envoy.extensions.http.cache.file_system_http_cache.v3B\030FileSystemHttpCacheProtoP\001Zugithub.com/envoyproxy/go-control-plane/envoy/extensions/http/cache/file_system_http_cache/v3;file_system_http_cachev3\272\200\310\321\006\002\020\002\322\306\244\341\006\002\010\001'
  _FILESYSTEMHTTPCACHECONFIG.fields_by_name['manager_config']._options = None
  _FILESYSTEMHTTPCACHECONFIG.fields_by_name['manager_config']._serialized_options = b'\372B\005\212\001\002\020\001'
  _FILESYSTEMHTTPCACHECONFIG.fields_by_name['cache_path']._options = None
  _FILESYSTEMHTTPCACHECONFIG.fields_by_name['cache_path']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_FILESYSTEMHTTPCACHECONFIG']._serialized_start=360
  _globals['_FILESYSTEMHTTPCACHECONFIG']._serialized_end=903
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/trace/v3/service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import grpc_service_pb2 as envoy_dot_config_dot_core_dot_v3_dot_grpc__service__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#envoy/config/trace/v3/service.proto\x12\x15\x65nvoy.config.trace.v3\x1a\'envoy/config/core/v3/grpc_service.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x88\x01\n\x12TraceServiceConfig\x12\x41\n\x0cgrpc_service\x18\x01 \x01(\x0b\x32!.envoy.config.core.v3.GrpcServiceB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01:/\x9a\xc5\x88\x1e*\n(envoy.config.trace.v2.TraceServiceConfigB\x83\x01\n#io.envoyproxy.envoy.config.trace.v3B\x0cServiceProtoP\x01ZDgithub.com/envoyproxy/go-control-plane/envoy/config/trace/v3;tracev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.trace.v3.service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.envoyproxy.envoy.config.trace.v3B\014ServiceProtoP\001ZDgithub.com/envoyproxy/go-control-plane/envoy/config/trace/v3;tracev3\272\200\310\321\006\002\020\002'
  _TRACESERVICECONFIG.fields_by_name['grpc_service']._options = None
  _TRACESERVICECONFIG.fields_by_name['grpc_service']._serialized_options = b'\372B\005\212\001\002\020\001'
  _TRACESERVICECONFIG._options = None
  _TRACESERVICECONFIG._serialized_options = b'\232\305\210\036*\n(envoy.config.trace.v2.TraceServiceConfig'
  _globals['_TRACESERVICECONFIG']._serialized_start=195
  _globals['_TRACESERVICECONFIG']._serialized_end=331
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/data/tap/v3/common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x65nvoy/data/tap/v3/common.proto\x12\x11\x65nvoy.data.tap.v3\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"s\n\x04\x42ody\x12\x12\n\x08\x61s_bytes\x18\x01 \x01(\x0cH\x00\x12\x13\n\tas_string\x18\x02 \x01(\tH\x00\x12\x11\n\ttruncated\x18\x03 \x01(\x08:\"\x9a\xc5\x88\x1e\x1d\n\x1b\x65nvoy.data.tap.v2alpha.BodyB\x0b\n\tbody_typeBx\n\x1fio.envoyproxy.envoy.data.tap.v3B\x0b\x43ommonProtoP\x01Z>github.com/envoyproxy/go-control-plane/envoy/data/tap/v3;tapv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.data.tap.v3.common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037io.envoyproxy.envoy.data.tap.v3B\013CommonProtoP\001Z>github.com/envoyproxy/go-control-plane/envoy/data/tap/v3;tapv3\272\200\310\321\006\002\020\002'
  _BODY._options = None
  _BODY._serialized_options = b'\232\305\210\036\035\n\033envoy.data.tap.v2alpha.Body'
  _globals['_BODY']._serialized_start=119
  _globals['_BODY']._serialized_end=234
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/transport_sockets/tap/v3/tap.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.extensions.common.tap.v3 import common_pb2 as envoy_dot_extensions_dot_common_dot_tap_dot_v3_dot_common__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3envoy/extensions/transport_sockets/tap/v3/tap.proto\x12)envoy.extensions.transport_sockets.tap.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a+envoy/extensions/common/tap/v3/common.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xde\x01\n\x03Tap\x12V\n\rcommon_config\x18\x01 \x01(\x0b\x32\x35.envoy.extensions.common.tap.v3.CommonExtensionConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12I\n\x10transport_socket\x18\x02 \x01(\x0b\x32%.envoy.config.core.v3.TransportSocketB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01:4\x9a\xc5\x88\x1e/\n-envoy.config.transport_socket.tap.v2alpha.TapB\xa5\x01\n7io.envoyproxy.envoy.extensions.transport_sockets.tap.v3B\x08TapProtoP\x01ZVgithub.com/envoyproxy/go-control-plane/envoy/extensions/transport_sockets/tap/v3;tapv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.transport_sockets.tap.v3.tap_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n7io.envoyproxy.envoy.extensions.transport_sockets.tap.v3B\010TapProtoP\001ZVgithub.com/envoyproxy/go-control-plane/envoy/extensions/transport_sockets/tap/v3;tapv3\272\200\310\321\006\002\020\002'
  _TAP.fields_by_name['common_config']._options = None
  _TAP.fields_by_name['common_config']._serialized_options = b'\372B\005\212\001\002\020\001'
  _TAP.fields_by_name['transport_socket']._options = None
  _TAP.fields_by_name['transport_socket']._serialized_options = b'\372B\005\212\001\002\020\001'
  _TAP._options = None
  _TAP._serialized_options = b'\232\305\210\036/\n-envoy.config.transport_socket.tap.v2alpha.Tap'
  _globals['_TAP']._serialized_start=268
  _globals['_TAP']._serialized_end=490
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/data/tap/v3/wrapper.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.data.tap.v3 import http_pb2 as envoy_dot_data_dot_tap_dot_v3_dot_http__pb2
from envoy.data.tap.v3 import transport_pb2 as envoy_dot_data_dot_tap_dot_v3_dot_transport__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x65nvoy/data/tap/v3/wrapper.proto\x12\x11\x65nvoy.data.tap.v3\x1a\x1c\x65nvoy/data/tap/v3/http.proto\x1a!envoy/data/tap/v3/transport.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x82\x03\n\x0cTraceWrapper\x12\x43\n\x13http_buffered_trace\x18\x01 \x01(\x0b\x32$.envoy.data.tap.v3.HttpBufferedTraceH\x00\x12R\n\x1bhttp_streamed_trace_segment\x18\x02 \x01(\x0b\x32+.envoy.data.tap.v3.HttpStreamedTraceSegmentH\x00\x12G\n\x15socket_buffered_trace\x18\x03 \x01(\x0b\x32&.envoy.data.tap.v3.SocketBufferedTraceH\x00\x12V\n\x1dsocket_streamed_trace_segment\x18\x04 \x01(\x0b\x32-.envoy.data.tap.v3.SocketStreamedTraceSegmentH\x00:*\x9a\xc5\x88\x1e%\n#envoy.data.tap.v2alpha.TraceWrapperB\x0c\n\x05trace\x12\x03\xf8\x42\x01\x42y\n\x1fio.envoyproxy.envoy.data.tap.v3B\x0cWrapperProtoP\x01Z>github.com/envoyproxy/go-control-plane/envoy/data/tap/v3;tapv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.data.tap.v3.wrapper_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037io.envoyproxy.envoy.data.tap.v3B\014WrapperProtoP\001Z>github.com/envoyproxy/go-control-plane/envoy/data/tap/v3;tapv3\272\200\310\321\006\002\020\002'
  _TRACEWRAPPER.oneofs_by_name['trace']._options = None
  _TRACEWRAPPER.oneofs_by_name['trace']._serialized_options = b'\370B\001'
  _TRACEWRAPPER._options = None
  _TRACEWRAPPER._serialized_options = b'\232\305\210\036%\n#envoy.data.tap.v2alpha.TraceWrapper'
  _globals['_TRACEWRAPPER']._serialized_start=211
  _globals['_TRACEWRAPPER']._serialized_end=597
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/resource.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19google/api/resource.proto\x12\ngoogle.api\x1a google/protobuf/descriptor.proto\"\xee\x02\n\x12ResourceDescriptor\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0f\n\x07pattern\x18\x02 \x03(\t\x12\x12\n\nname_field\x18\x03 \x01(\t\x12\x37\n\x07history\x18\x04 \x01(\x0e\x32&.google.api.ResourceDescriptor.History\x12\x0e\n\x06plural\x18\x05 \x01(\t\x12\x10\n\x08singular\x18\x06 \x01(\t\x12\x33\n\x05style\x18\n \x03(\x0e\x32$.google.api.ResourceDescriptor.Style\"[\n\x07History\x12\x17\n\x13HISTORY_UNSPECIFIED\x10\x00\x12\x1d\n\x19ORIGINALLY_SINGLE_PATTERN\x10\x01\x12\x18\n\x14\x46UTURE_MULTI_PATTERN\x10\x02\"8\n\x05Style\x12\x15\n\x11STYLE_UNSPECIFIED\x10\x00\x12\x18\n\x14\x44\x45\x43LARATIVE_FRIENDLY\x10\x01\"5\n\x11ResourceReference\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x12\n\nchild_type\x18\x02 \x01(\t:Y\n\x12resource_reference\x12\x1d.google.protobuf.FieldOptions\x18\x9f\x08 \x01(\x0b\x32\x1d.google.api.ResourceReference:Z\n\x13resource_definition\x12\x1c.google.protobuf.FileOptions\x18\x9d\x08 \x03(\x0b\x32\x1e.google.api.ResourceDescriptor:R\n\x08resource\x12\x1f.google.protobuf.MessageOptions\x18\x9d\x08 \x01(\x0b\x32\x1e.google.api.ResourceDescriptorBn\n\x0e\x63om.google.apiB\rResourceProtoP\x01ZAgoogle.golang.org/genproto/googleapis/api/annotations;annotations\xf8\x01\x01\xa2\x02\x04GAPIb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.resource_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(resource_reference)
  google_dot_protobuf_dot_descriptor__pb2.FileOptions.RegisterExtension(resource_definition)
  google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(resource)

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\016com.google.apiB\rResourceProtoP\001ZAgoogle.golang.org/genproto/googleapis/api/annotations;annotations\370\001\001\242\002\004GAPI'
  _globals['_RESOURCEDESCRIPTOR']._serialized_start=76
  _globals['_RESOURCEDESCRIPTOR']._serialized_end=442
  _globals['_RESOURCEDESCRIPTOR_HISTORY']._serialized_start=293
  _globals['_RESOURCEDESCRIPTOR_HISTORY']._serialized_end=384
  _globals['_RESOURCEDESCRIPTOR_STYLE']._serialized_start=386
  _globals['_RESOURCEDESCRIPTOR_STYLE']._serialized_end=442
  _globals['_RESOURCEREFERENCE']._serialized_start=444
  _globals['_RESOURCEREFERENCE']._serialized_end=497
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/serviceusage/v1/resources.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import auth_pb2 as google_dot_api_dot_auth__pb2
from google.api import documentation_pb2 as google_dot_api_dot_documentation__pb2
from google.api import endpoint_pb2 as google_dot_api_dot_endpoint__pb2
from google.api import monitored_resource_pb2 as google_dot_api_dot_monitored__resource__pb2
from google.api import monitoring_pb2 as google_dot_api_dot_monitoring__pb2
from google.api import quota_pb2 as google_dot_api_dot_quota__pb2
from google.api import usage_pb2 as google_dot_api_dot_usage__pb2
from google.protobuf import api_pb2 as google_dot_protobuf_dot_api__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*google/api/serviceusage/v1/resources.proto\x12\x1agoogle.api.serviceusage.v1\x1a\x15google/api/auth.proto\x1a\x1egoogle/api/documentation.proto\x1a\x19google/api/endpoint.proto\x1a#google/api/monitored_resource.proto\x1a\x1bgoogle/api/monitoring.proto\x1a\x16google/api/quota.proto\x1a\x16google/api/usage.proto\x1a\x19google/protobuf/api.proto\x1a\x1cgoogle/api/annotations.proto\"\x94\x01\n\x07Service\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06parent\x18\x05 \x01(\t\x12\x39\n\x06\x63onfig\x18\x02 \x01(\x0b\x32).google.api.serviceusage.v1.ServiceConfig\x12\x30\n\x05state\x18\x04 \x01(\x0e\x32!.google.api.serviceusage.v1.State\"\x95\x03\n\rServiceConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\"\n\x04\x61pis\x18\x03 \x03(\x0b\x32\x14.google.protobuf.Api\x12\x30\n\rdocumentation\x18\x06 \x01(\x0b\x32\x19.google.api.Documentation\x12 \n\x05quota\x18\n \x01(\x0b\x32\x11.google.api.Quota\x12\x32\n\x0e\x61uthentication\x18\x0b \x01(\x0b\x32\x1a.google.api.Authentication\x12 \n\x05usage\x18\x0f \x01(\x0b\x32\x11.google.api.Usage\x12\'\n\tendpoints\x18\x12 \x03(\x0b\x32\x14.google.api.Endpoint\x12\x44\n\x13monitored_resources\x18\x19 \x03(\x0b\x32\'.google.api.MonitoredResourceDescriptor\x12*\n\nmonitoring\x18\x1c \x01(\x0b\x32\x16.google.api.Monitoring\"+\n\x11OperationMetadata\x12\x16\n\x0eresource_names\x18\x02 \x03(\t*9\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x44ISABLED\x10\x01\x12\x0b\n\x07\x45NABLED\x10\x02\x42\xda\x01\n\x1e\x63om.google.api.serviceusage.v1B\x0eResourcesProtoP\x01ZFgoogle.golang.org/genproto/googleapis/api/serviceusage/v1;serviceusage\xaa\x02\x1cGoogle.Cloud.ServiceUsage.V1\xca\x02\x1cGoogle\\Cloud\\ServiceUsage\\V1\xea\x02\x1fGoogle::Cloud::ServiceUsage::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.serviceusage.v1.resources_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036com.google.api.serviceusage.v1B\016ResourcesProtoP\001ZFgoogle.golang.org/genproto/googleapis/api/serviceusage/v1;serviceusage\252\002\034Google.Cloud.ServiceUsage.V1\312\002\034Google\\Cloud\\ServiceUsage\\V1\352\002\037Google::Cloud::ServiceUsage::V1'
  _globals['_STATE']._serialized_start=931
  _globals['_STATE']._serialized_end=988
  _globals['_SERVICE']._serialized_start=328
  _globals['_SERVICE']._serialized_end=476
  _globals['_SERVICECONFIG']._serialized_start=479
  _globals['_SERVICECONFIG']._serialized_end=884
  _globals['_OPERATIONMETADATA']._serialized_start=886
  _globals['_OPERATIONMETADATA']._serialized_end=929
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/type/matcher/regex.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x65nvoy/type/matcher/regex.proto\x12\x12\x65nvoy.type.matcher\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xcf\x01\n\x0cRegexMatcher\x12J\n\ngoogle_re2\x18\x01 \x01(\x0b\x32*.envoy.type.matcher.RegexMatcher.GoogleRE2B\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00\x12\x16\n\x05regex\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x1aG\n\tGoogleRE2\x12:\n\x10max_program_size\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x02\x18\x01\x42\x12\n\x0b\x65ngine_type\x12\x03\xf8\x42\x01\"b\n\x17RegexMatchAndSubstitute\x12\x31\n\x07pattern\x18\x01 \x01(\x0b\x32 .envoy.type.matcher.RegexMatcher\x12\x14\n\x0csubstitution\x18\x02 \x01(\tBs\n io.envoyproxy.envoy.type.matcherB\nRegexProtoP\x01Z9github.com/envoyproxy/go-control-plane/envoy/type/matcher\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.type.matcher.regex_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n io.envoyproxy.envoy.type.matcherB\nRegexProtoP\001Z9github.com/envoyproxy/go-control-plane/envoy/type/matcher\272\200\310\321\006\002\020\001'
  _REGEXMATCHER_GOOGLERE2.fields_by_name['max_program_size']._options = None
  _REGEXMATCHER_GOOGLERE2.fields_by_name['max_program_size']._serialized_options = b'\030\001'
  _REGEXMATCHER.oneofs_by_name['engine_type']._options = None
  _REGEXMATCHER.oneofs_by_name['engine_type']._serialized_options = b'\370B\001'
  _REGEXMATCHER.fields_by_name['google_re2']._options = None
  _REGEXMATCHER.fields_by_name['google_re2']._serialized_options = b'\372B\005\212\001\002\020\001'
  _REGEXMATCHER.fields_by_name['regex']._options = None
  _REGEXMATCHER.fields_by_name['regex']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_REGEXMATCHER']._serialized_start=143
  _globals['_REGEXMATCHER']._serialized_end=350
  _globals['_REGEXMATCHER_GOOGLERE2']._serialized_start=259
  _globals['_REGEXMATCHER_GOOGLERE2']._serialized_end=330
  _globals['_REGEXMATCHANDSUBSTITUTE']._serialized_start=352
  _globals['_REGEXMATCHANDSUBSTITUTE']._serialized_end=450
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/trace/v3/opencensus.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import grpc_service_pb2 as envoy_dot_config_dot_core_dot_v3_dot_grpc__service__pb2
from opencensus.proto.trace.v1 import trace_config_pb2 as opencensus_dot_proto_dot_trace_dot_v1_dot_trace__config__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&envoy/config/trace/v3/opencensus.proto\x12\x15\x65nvoy.config.trace.v3\x1a\'envoy/config/core/v3/grpc_service.proto\x1a,opencensus/proto/trace/v1/trace_config.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"\xa7\x06\n\x10OpenCensusConfig\x12<\n\x0ctrace_config\x18\x01 \x01(\x0b\x32&.opencensus.proto.trace.v1.TraceConfig\x12\x1f\n\x17stdout_exporter_enabled\x18\x02 \x01(\x08\x12$\n\x1cstackdriver_exporter_enabled\x18\x03 \x01(\x08\x12\x1e\n\x16stackdriver_project_id\x18\x04 \x01(\t\x12\x1b\n\x13stackdriver_address\x18\n \x01(\t\x12\x43\n\x18stackdriver_grpc_service\x18\r \x01(\x0b\x32!.envoy.config.core.v3.GrpcService\x12,\n\x17zipkin_exporter_enabled\x18\x05 \x01(\x08\x42\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12\x1f\n\nzipkin_url\x18\x06 \x01(\tB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12 \n\x18ocagent_exporter_enabled\x18\x0b \x01(\x08\x12\x17\n\x0focagent_address\x18\x0c \x01(\t\x12?\n\x14ocagent_grpc_service\x18\x0e \x01(\x0b\x32!.envoy.config.core.v3.GrpcService\x12T\n\x16incoming_trace_context\x18\x08 \x03(\x0e\x32\x34.envoy.config.trace.v3.OpenCensusConfig.TraceContext\x12T\n\x16outgoing_trace_context\x18\t \x03(\x0e\x32\x34.envoy.config.trace.v3.OpenCensusConfig.TraceContext\"`\n\x0cTraceContext\x12\x08\n\x04NONE\x10\x00\x12\x11\n\rTRACE_CONTEXT\x10\x01\x12\x12\n\x0eGRPC_TRACE_BIN\x10\x02\x12\x17\n\x13\x43LOUD_TRACE_CONTEXT\x10\x03\x12\x06\n\x02\x42\x33\x10\x04:-\x9a\xc5\x88\x1e(\n&envoy.config.trace.v2.OpenCensusConfigJ\x04\x08\x07\x10\x08\x42\xb9\x01\n#io.envoyproxy.envoy.config.trace.v3B\x0fOpencensusProtoP\x01ZDgithub.com/envoyproxy/go-control-plane/envoy/config/trace/v3;tracev3\xf2\x98\xfe\x8f\x05-\x12+envoy.extensions.tracers.opencensus.v4alpha\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.trace.v3.opencensus_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.envoyproxy.envoy.config.trace.v3B\017OpencensusProtoP\001ZDgithub.com/envoyproxy/go-control-plane/envoy/config/trace/v3;tracev3\362\230\376\217\005-\022+envoy.extensions.tracers.opencensus.v4alpha\272\200\310\321\006\002\020\002'
  _OPENCENSUSCONFIG.fields_by_name['zipkin_exporter_enabled']._options = None
  _OPENCENSUSCONFIG.fields_by_name['zipkin_exporter_enabled']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _OPENCENSUSCONFIG.fields_by_name['zipkin_url']._options = None
  _OPENCENSUSCONFIG.fields_by_name['zipkin_url']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _OPENCENSUSCONFIG._options = None
  _OPENCENSUSCONFIG._serialized_options = b'\232\305\210\036(\n&envoy.config.trace.v2.OpenCensusConfig'
  _globals['_OPENCENSUSCONFIG']._serialized_start=288
  _globals['_OPENCENSUSCONFIG']._serialized_end=1095
  _globals['_OPENCENSUSCONFIG_TRACECONTEXT']._serialized_start=946
  _globals['_OPENCENSUSCONFIG_TRACECONTEXT']._serialized_end=1042
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/access_loggers/open_telemetry/v3/logs_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.extensions.access_loggers.grpc.v3 import als_pb2 as envoy_dot_extensions_dot_access__loggers_dot_grpc_dot_v3_dot_als__pb2
from opentelemetry.proto.common.v1 import common_pb2 as opentelemetry_dot_proto_dot_common_dot_v1_dot_common__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDenvoy/extensions/access_loggers/open_telemetry/v3/logs_service.proto\x12\x31\x65nvoy.extensions.access_loggers.open_telemetry.v3\x1a\x31\x65nvoy/extensions/access_loggers/grpc/v3/als.proto\x1a*opentelemetry/proto/common/v1/common.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xc5\x02\n\x1cOpenTelemetryAccessLogConfig\x12\x63\n\rcommon_config\x18\x01 \x01(\x0b\x32\x42.envoy.extensions.access_loggers.grpc.v3.CommonGrpcAccessLogConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12H\n\x13resource_attributes\x18\x04 \x01(\x0b\x32+.opentelemetry.proto.common.v1.KeyValueList\x12\x35\n\x04\x62ody\x18\x02 \x01(\x0b\x32\'.opentelemetry.proto.common.v1.AnyValue\x12?\n\nattributes\x18\x03 \x01(\x0b\x32+.opentelemetry.proto.common.v1.KeyValueListB\xc8\x01\n?io.envoyproxy.envoy.extensions.access_loggers.open_telemetry.v3B\x10LogsServiceProtoP\x01Zigithub.com/envoyproxy/go-control-plane/envoy/extensions/access_loggers/open_telemetry/v3;open_telemetryv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.access_loggers.open_telemetry.v3.logs_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n?io.envoyproxy.envoy.extensions.access_loggers.open_telemetry.v3B\020LogsServiceProtoP\001Zigithub.com/envoyproxy/go-control-plane/envoy/extensions/access_loggers/open_telemetry/v3;open_telemetryv3\272\200\310\321\006\002\020\002'
  _OPENTELEMETRYACCESSLOGCONFIG.fields_by_name['common_config']._options = None
  _OPENTELEMETRYACCESSLOGCONFIG.fields_by_name['common_config']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_OPENTELEMETRYACCESSLOGCONFIG']._serialized_start=275
  _globals['_OPENTELEMETRYACCESSLOGCONFIG']._serialized_end=600
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/accesslog/v2/als.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import grpc_service_pb2 as envoy_dot_api_dot_v2_dot_core_dot_grpc__service__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#envoy/config/accesslog/v2/als.proto\x12\x19\x65nvoy.config.accesslog.v2\x1a$envoy/api/v2/core/grpc_service.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xf4\x01\n\x17HttpGrpcAccessLogConfig\x12U\n\rcommon_config\x18\x01 \x01(\x0b\x32\x34.envoy.config.accesslog.v2.CommonGrpcAccessLogConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12)\n!additional_request_headers_to_log\x18\x02 \x03(\t\x12*\n\"additional_response_headers_to_log\x18\x03 \x03(\t\x12+\n#additional_response_trailers_to_log\x18\x04 \x03(\t\"o\n\x16TcpGrpcAccessLogConfig\x12U\n\rcommon_config\x18\x01 \x01(\x0b\x32\x34.envoy.config.accesslog.v2.CommonGrpcAccessLogConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"\x98\x02\n\x19\x43ommonGrpcAccessLogConfig\x12\x19\n\x08log_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12>\n\x0cgrpc_service\x18\x02 \x01(\x0b\x32\x1e.envoy.api.v2.core.GrpcServiceB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x42\n\x15\x62uffer_flush_interval\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12\x37\n\x11\x62uffer_size_bytes\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12#\n\x1b\x66ilter_state_objects_to_log\x18\x05 \x03(\tB\xba\x01\n\'io.envoyproxy.envoy.config.accesslog.v2B\x08\x41lsProtoP\x01ZLgithub.com/envoyproxy/go-control-plane/envoy/config/accesslog/v2;accesslogv2\xf2\x98\xfe\x8f\x05)\x12\'envoy.extensions.access_loggers.grpc.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.accesslog.v2.als_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\'io.envoyproxy.envoy.config.accesslog.v2B\010AlsProtoP\001ZLgithub.com/envoyproxy/go-control-plane/envoy/config/accesslog/v2;accesslogv2\362\230\376\217\005)\022\'envoy.extensions.access_loggers.grpc.v3\272\200\310\321\006\002\020\001'
  _HTTPGRPCACCESSLOGCONFIG.fields_by_name['common_config']._options = None
  _HTTPGRPCACCESSLOGCONFIG.fields_by_name['common_config']._serialized_options = b'\372B\005\212\001\002\020\001'
  _TCPGRPCACCESSLOGCONFIG.fields_by_name['common_config']._options = None
  _TCPGRPCACCESSLOGCONFIG.fields_by_name['common_config']._serialized_options = b'\372B\005\212\001\002\020\001'
  _COMMONGRPCACCESSLOGCONFIG.fields_by_name['log_name']._options = None
  _COMMONGRPCACCESSLOGCONFIG.fields_by_name['log_name']._serialized_options = b'\372B\004r\002 \001'
  _COMMONGRPCACCESSLOGCONFIG.fields_by_name['grpc_service']._options = None
  _COMMONGRPCACCESSLOGCONFIG.fields_by_name['grpc_service']._serialized_options = b'\372B\005\212\001\002\020\001'
  _COMMONGRPCACCESSLOGCONFIG.fields_by_name['buffer_flush_interval']._options = None
  _COMMONGRPCACCESSLOGCONFIG.fields_by_name['buffer_flush_interval']._serialized_options = b'\372B\005\252\001\002*\000'
  _globals['_HTTPGRPCACCESSLOGCONFIG']._serialized_start=257
  _globals['_HTTPGRPCACCESSLOGCONFIG']._serialized_end=501
  _globals['_TCPGRPCACCESSLOGCONFIG']._serialized_start=503
  _globals['_TCPGRPCACCESSLOGCONFIG']._serialized_end=614
  _globals['_COMMONGRPCACCESSLOGCONFIG']._serialized_start=617
  _globals['_COMMONGRPCACCESSLOGCONFIG']._serialized_end=897
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/original_src/v3/original_src.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@envoy/extensions/filters/http/original_src/v3/original_src.proto\x12-envoy.extensions.filters.http.original_src.v3\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"^\n\x0bOriginalSrc\x12\x0c\n\x04mark\x18\x01 \x01(\r:A\x9a\xc5\x88\x1e<\n:envoy.config.filter.http.original_src.v2alpha1.OriginalSrcB\xbe\x01\n;io.envoyproxy.envoy.extensions.filters.http.original_src.v3B\x10OriginalSrcProtoP\x01Zcgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/original_src/v3;original_srcv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.original_src.v3.original_src_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n;io.envoyproxy.envoy.extensions.filters.http.original_src.v3B\020OriginalSrcProtoP\001Zcgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/original_src/v3;original_srcv3\272\200\310\321\006\002\020\002'
  _ORIGINALSRC._options = None
  _ORIGINALSRC._serialized_options = b'\232\305\210\036<\n:envoy.config.filter.http.original_src.v2alpha1.OriginalSrc'
  _globals['_ORIGINALSRC']._serialized_start=181
  _globals['_ORIGINALSRC']._serialized_end=275
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/expr/v1alpha1/syntax.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%google/api/expr/v1alpha1/syntax.proto\x12\x18google.api.expr.v1alpha1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"u\n\nParsedExpr\x12,\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.Expr\x12\x39\n\x0bsource_info\x18\x03 \x01(\x0b\x32$.google.api.expr.v1alpha1.SourceInfo\"\xc5\n\n\x04\x45xpr\x12\n\n\x02id\x18\x02 \x01(\x03\x12\x38\n\nconst_expr\x18\x03 \x01(\x0b\x32\".google.api.expr.v1alpha1.ConstantH\x00\x12:\n\nident_expr\x18\x04 \x01(\x0b\x32$.google.api.expr.v1alpha1.Expr.IdentH\x00\x12<\n\x0bselect_expr\x18\x05 \x01(\x0b\x32%.google.api.expr.v1alpha1.Expr.SelectH\x00\x12\x38\n\tcall_expr\x18\x06 \x01(\x0b\x32#.google.api.expr.v1alpha1.Expr.CallH\x00\x12>\n\tlist_expr\x18\x07 \x01(\x0b\x32).google.api.expr.v1alpha1.Expr.CreateListH\x00\x12\x42\n\x0bstruct_expr\x18\x08 \x01(\x0b\x32+.google.api.expr.v1alpha1.Expr.CreateStructH\x00\x12J\n\x12\x63omprehension_expr\x18\t \x01(\x0b\x32,.google.api.expr.v1alpha1.Expr.ComprehensionH\x00\x1a\x15\n\x05Ident\x12\x0c\n\x04name\x18\x01 \x01(\t\x1a[\n\x06Select\x12/\n\x07operand\x18\x01 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.Expr\x12\r\n\x05\x66ield\x18\x02 \x01(\t\x12\x11\n\ttest_only\x18\x03 \x01(\x08\x1av\n\x04\x43\x61ll\x12.\n\x06target\x18\x01 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.Expr\x12\x10\n\x08\x66unction\x18\x02 \x01(\t\x12,\n\x04\x61rgs\x18\x03 \x03(\x0b\x32\x1e.google.api.expr.v1alpha1.Expr\x1a>\n\nCreateList\x12\x30\n\x08\x65lements\x18\x01 \x03(\x0b\x32\x1e.google.api.expr.v1alpha1.Expr\x1a\x81\x02\n\x0c\x43reateStruct\x12\x14\n\x0cmessage_name\x18\x01 \x01(\t\x12\x42\n\x07\x65ntries\x18\x02 \x03(\x0b\x32\x31.google.api.expr.v1alpha1.Expr.CreateStruct.Entry\x1a\x96\x01\n\x05\x45ntry\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x13\n\tfield_key\x18\x02 \x01(\tH\x00\x12\x31\n\x07map_key\x18\x03 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.ExprH\x00\x12-\n\x05value\x18\x04 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.ExprB\n\n\x08key_kind\x1a\xb5\x02\n\rComprehension\x12\x10\n\x08iter_var\x18\x01 \x01(\t\x12\x32\n\niter_range\x18\x02 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.Expr\x12\x10\n\x08\x61\x63\x63u_var\x18\x03 \x01(\t\x12\x31\n\taccu_init\x18\x04 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.Expr\x12\x36\n\x0eloop_condition\x18\x05 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.Expr\x12\x31\n\tloop_step\x18\x06 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.Expr\x12.\n\x06result\x18\x07 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.ExprB\x0b\n\texpr_kind\"\xcd\x02\n\x08\x43onstant\x12\x30\n\nnull_value\x18\x01 \x01(\x0e\x32\x1a.google.protobuf.NullValueH\x00\x12\x14\n\nbool_value\x18\x02 \x01(\x08H\x00\x12\x15\n\x0bint64_value\x18\x03 \x01(\x03H\x00\x12\x16\n\x0cuint64_value\x18\x04 \x01(\x04H\x00\x12\x16\n\x0c\x64ouble_value\x18\x05 \x01(\x01H\x00\x12\x16\n\x0cstring_value\x18\x06 \x01(\tH\x00\x12\x15\n\x0b\x62ytes_value\x18\x07 \x01(\x0cH\x00\x12\x37\n\x0e\x64uration_value\x18\x08 \x01(\x0b\x32\x19.google.protobuf.DurationB\x02\x18\x01H\x00\x12\x39\n\x0ftimestamp_value\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x02\x18\x01H\x00\x42\x0f\n\rconstant_kind\"\xe4\x02\n\nSourceInfo\x12\x16\n\x0esyntax_version\x18\x01 \x01(\t\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x14\n\x0cline_offsets\x18\x03 \x03(\x05\x12\x46\n\tpositions\x18\x04 \x03(\x0b\x32\x33.google.api.expr.v1alpha1.SourceInfo.PositionsEntry\x12I\n\x0bmacro_calls\x18\x05 \x03(\x0b\x32\x34.google.api.expr.v1alpha1.SourceInfo.MacroCallsEntry\x1a\x30\n\x0ePositionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\x1aQ\n\x0fMacroCallsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12-\n\x05value\x18\x02 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.Expr:\x02\x38\x01\"P\n\x0eSourcePosition\x12\x10\n\x08location\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\x05\x12\x0c\n\x04line\x18\x03 \x01(\x05\x12\x0e\n\x06\x63olumn\x18\x04 \x01(\x05\x42n\n\x1c\x63om.google.api.expr.v1alpha1B\x0bSyntaxProtoP\x01Z<google.golang.org/genproto/googleapis/api/expr/v1alpha1;expr\xf8\x01\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.expr.v1alpha1.syntax_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\034com.google.api.expr.v1alpha1B\013SyntaxProtoP\001Z<google.golang.org/genproto/googleapis/api/expr/v1alpha1;expr\370\001\001'
  _CONSTANT.fields_by_name['duration_value']._options = None
  _CONSTANT.fields_by_name['duration_value']._serialized_options = b'\030\001'
  _CONSTANT.fields_by_name['timestamp_value']._options = None
  _CONSTANT.fields_by_name['timestamp_value']._serialized_options = b'\030\001'
  _SOURCEINFO_POSITIONSENTRY._options = None
  _SOURCEINFO_POSITIONSENTRY._serialized_options = b'8\001'
  _SOURCEINFO_MACROCALLSENTRY._options = None
  _SOURCEINFO_MACROCALLSENTRY._serialized_options = b'8\001'
  _globals['_PARSEDEXPR']._serialized_start=162
  _globals['_PARSEDEXPR']._serialized_end=279
  _globals['_EXPR']._serialized_start=282
  _globals['_EXPR']._serialized_end=1631
  _globals['_EXPR_IDENT']._serialized_start=748
  _globals['_EXPR_IDENT']._serialized_end=769
  _globals['_EXPR_SELECT']._serialized_start=771
  _globals['_EXPR_SELECT']._serialized_end=862
  _globals['_EXPR_CALL']._serialized_start=864
  _globals['_EXPR_CALL']._serialized_end=982
  _globals['_EXPR_CREATELIST']._serialized_start=984
  _globals['_EXPR_CREATELIST']._serialized_end=1046
  _globals['_EXPR_CREATESTRUCT']._serialized_start=1049
  _globals['_EXPR_CREATESTRUCT']._serialized_end=1306
  _globals['_EXPR_CREATESTRUCT_ENTRY']._serialized_start=1156
  _globals['_EXPR_CREATESTRUCT_ENTRY']._serialized_end=1306
  _globals['_EXPR_COMPREHENSION']._serialized_start=1309
  _globals['_EXPR_COMPREHENSION']._serialized_end=1618
  _globals['_CONSTANT']._serialized_start=1634
  _globals['_CONSTANT']._serialized_end=1967
  _globals['_SOURCEINFO']._serialized_start=1970
  _globals['_SOURCEINFO']._serialized_end=2326
  _globals['_SOURCEINFO_POSITIONSENTRY']._serialized_start=2195
  _globals['_SOURCEINFO_POSITIONSENTRY']._serialized_end=2243
  _globals['_SOURCEINFO_MACROCALLSENTRY']._serialized_start=2245
  _globals['_SOURCEINFO_MACROCALLSENTRY']._serialized_end=2326
  _globals['_SOURCEPOSITION']._serialized_start=2328
  _globals['_SOURCEPOSITION']._serialized_end=2408
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/quota.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16google/api/quota.proto\x12\ngoogle.api\"]\n\x05Quota\x12&\n\x06limits\x18\x03 \x03(\x0b\x32\x16.google.api.QuotaLimit\x12,\n\x0cmetric_rules\x18\x04 \x03(\x0b\x32\x16.google.api.MetricRule\"\x91\x01\n\nMetricRule\x12\x10\n\x08selector\x18\x01 \x01(\t\x12=\n\x0cmetric_costs\x18\x02 \x03(\x0b\x32\'.google.api.MetricRule.MetricCostsEntry\x1a\x32\n\x10MetricCostsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\"\x95\x02\n\nQuotaLimit\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x15\n\rdefault_limit\x18\x03 \x01(\x03\x12\x11\n\tmax_limit\x18\x04 \x01(\x03\x12\x11\n\tfree_tier\x18\x07 \x01(\x03\x12\x10\n\x08\x64uration\x18\x05 \x01(\t\x12\x0e\n\x06metric\x18\x08 \x01(\t\x12\x0c\n\x04unit\x18\t \x01(\t\x12\x32\n\x06values\x18\n \x03(\x0b\x32\".google.api.QuotaLimit.ValuesEntry\x12\x14\n\x0c\x64isplay_name\x18\x0c \x01(\t\x1a-\n\x0bValuesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\x42l\n\x0e\x63om.google.apiB\nQuotaProtoP\x01ZEgoogle.golang.org/genproto/googleapis/api/serviceconfig;serviceconfig\xa2\x02\x04GAPIb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.quota_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\016com.google.apiB\nQuotaProtoP\001ZEgoogle.golang.org/genproto/googleapis/api/serviceconfig;serviceconfig\242\002\004GAPI'
  _METRICRULE_METRICCOSTSENTRY._options = None
  _METRICRULE_METRICCOSTSENTRY._serialized_options = b'8\001'
  _QUOTALIMIT_VALUESENTRY._options = None
  _QUOTALIMIT_VALUESENTRY._serialized_options = b'8\001'
  _globals['_QUOTA']._serialized_start=38
  _globals['_QUOTA']._serialized_end=131
  _globals['_METRICRULE']._serialized_start=134
  _globals['_METRICRULE']._serialized_end=279
  _globals['_METRICRULE_METRICCOSTSENTRY']._serialized_start=229
  _globals['_METRICRULE_METRICCOSTSENTRY']._serialized_end=279
  _globals['_QUOTALIMIT']._serialized_start=282
  _globals['_QUOTALIMIT']._serialized_end=559
  _globals['_QUOTALIMIT_VALUESENTRY']._serialized_start=514
  _globals['_QUOTALIMIT_VALUESENTRY']._serialized_end=559
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/documentation.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1egoogle/api/documentation.proto\x12\ngoogle.api\"\xbb\x01\n\rDocumentation\x12\x0f\n\x07summary\x18\x01 \x01(\t\x12\x1f\n\x05pages\x18\x05 \x03(\x0b\x32\x10.google.api.Page\x12,\n\x05rules\x18\x03 \x03(\x0b\x32\x1d.google.api.DocumentationRule\x12\x1e\n\x16\x64ocumentation_root_url\x18\x04 \x01(\t\x12\x18\n\x10service_root_url\x18\x06 \x01(\t\x12\x10\n\x08overview\x18\x02 \x01(\t\"[\n\x11\x44ocumentationRule\x12\x10\n\x08selector\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x1f\n\x17\x64\x65precation_description\x18\x03 \x01(\t\"I\n\x04Page\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x12\"\n\x08subpages\x18\x03 \x03(\x0b\x32\x10.google.api.PageBt\n\x0e\x63om.google.apiB\x12\x44ocumentationProtoP\x01ZEgoogle.golang.org/genproto/googleapis/api/serviceconfig;serviceconfig\xa2\x02\x04GAPIb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.documentation_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\016com.google.apiB\022DocumentationProtoP\001ZEgoogle.golang.org/genproto/googleapis/api/serviceconfig;serviceconfig\242\002\004GAPI'
  _globals['_DOCUMENTATION']._serialized_start=47
  _globals['_DOCUMENTATION']._serialized_end=234
  _globals['_DOCUMENTATIONRULE']._serialized_start=236
  _globals['_DOCUMENTATIONRULE']._serialized_end=327
  _globals['_PAGE']._serialized_start=329
  _globals['_PAGE']._serialized_end=402
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: udpa/annotations/status.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dudpa/annotations/status.proto\x12\x10udpa.annotations\x1a google/protobuf/descriptor.proto\"t\n\x10StatusAnnotation\x12\x18\n\x10work_in_progress\x18\x01 \x01(\x08\x12\x46\n\x16package_version_status\x18\x02 \x01(\x0e\x32&.udpa.annotations.PackageVersionStatus*]\n\x14PackageVersionStatus\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06\x46ROZEN\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12 \n\x1cNEXT_MAJOR_VERSION_CANDIDATE\x10\x03:X\n\x0b\x66ile_status\x12\x1c.google.protobuf.FileOptions\x18\x87\x80\x99j \x01(\x0b\x32\".udpa.annotations.StatusAnnotationB$Z\"github.com/cncf/xds/go/annotationsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'udpa.annotations.status_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  google_dot_protobuf_dot_descriptor__pb2.FileOptions.RegisterExtension(file_status)

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\"github.com/cncf/xds/go/annotations'
  _globals['_PACKAGEVERSIONSTATUS']._serialized_start=203
  _globals['_PACKAGEVERSIONSTATUS']._serialized_end=296
  _globals['_STATUSANNOTATION']._serialized_start=85
  _globals['_STATUSANNOTATION']._serialized_end=201
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/listener/quic_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'envoy/api/v2/listener/quic_config.proto\x12\x15\x65nvoy.api.v2.listener\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\"\xc1\x01\n\x13QuicProtocolOptions\x12<\n\x16max_concurrent_streams\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12/\n\x0cidle_timeout\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12;\n\x18\x63rypto_handshake_timeout\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\xd5\x01\n#io.envoyproxy.envoy.api.v2.listenerB\x0fQuicConfigProtoP\x01Z<github.com/envoyproxy/go-control-plane/envoy/api/v2/listener\xaa\x02\x17\x45nvoy.Api.V2.ListenerNS\xea\x02\x1a\x45nvoy::Api::V2::ListenerNS\xf2\x98\xfe\x8f\x05\x1a\x12\x18\x65nvoy.config.listener.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.api.v2.listener.quic_config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.envoyproxy.envoy.api.v2.listenerB\017QuicConfigProtoP\001Z<github.com/envoyproxy/go-control-plane/envoy/api/v2/listener\252\002\027Envoy.Api.V2.ListenerNS\352\002\032Envoy::Api::V2::ListenerNS\362\230\376\217\005\032\022\030envoy.config.listener.v3\272\200\310\321\006\002\020\001'
  _globals['_QUICPROTOCOLOPTIONS']._serialized_start=194
  _globals['_QUICPROTOCOLOPTIONS']._serialized_end=387
# @@protoc_insertion_point(module_scope)
